# yatgl
Yet Another TeleGram Library (YATGL) is a Telegram library for NationStates.

To use it, run
```commandline
pip install yatgl
```

A barebones example of how YATGL can be used to send telegrams can be found in `example.py`.
